@@ -9,6 +9,8 @@
 #' or `"all"` to compute all tests. For each "test", the corresponding
 #' **bayestestR** function is called (e.g. [bayestestR::rope()] or
 #' [bayestestR::p_direction()]) and its results included in the summary output.
+#' @param ... Arguments passed to other methods, like [`bootstrap_model()`] or
+#' [`bayestestR::describe_posterior()`].
 #' @inheritParams bootstrap_model
 #' @inheritParams bayestestR::describe_posterior
 #'
@@ -40,6 +42,11 @@
 #' b <- bootstrap_parameters(model)
 #' print(b)
 #'
+#' # different type of bootstrapping
+#' set.seed(2)
+#' b <- bootstrap_parameters(model, type = "balanced")
+#' print(b)
+#'
 #' est <- emmeans::emmeans(b, trt.vs.ctrl ~ Species)
 #' print(model_parameters(est))
 #' }
@@ -60,8 +67,8 @@ bootstrap_parameters.default <- function(model,
                                          ci_method = "quantile",
                                          test = "p-value",
                                          ...) {
-  data <- bootstrap_model(model, iterations = iterations, ...)
-  bootstrap_parameters(data, centrality = centrality, ci = ci, ci_method = ci_method, test = test, ...)
+  boot_data <- bootstrap_model(model, iterations = iterations, ...)
+  bootstrap_parameters(boot_data, centrality = centrality, ci = ci, ci_method = ci_method, test = test, ...)
 }
 
 
