@@ -63,7 +63,6 @@ model_parameters.BFBayesFactor <- function(model,
                                            es_type = NULL,
                                            include_proportions = FALSE,
                                            verbose = TRUE,
-                                           effectsize_type = NULL,
                                            ...) {
   insight::check_if_installed("BayesFactor")
 
@@ -84,12 +83,6 @@ model_parameters.BFBayesFactor <- function(model,
     return(NULL)
   }
 
-  ## TODO: remove deprecation warning later
-  if (!is.null(effectsize_type)) {
-    insight::format_warning("Argument `effectsize_type` is deprecated. Use `es_type` instead.")
-    es_type <- effectsize_type
-  }
-
   out <- bayestestR::describe_posterior(
     model,
     centrality = centrality,
@@ -143,12 +136,12 @@ model_parameters.BFBayesFactor <- function(model,
     # needs {effectsize} to be installed
     insight::check_if_installed("effectsize")
 
-    ## TODO: add back ci-argument, once effectsize >= 0.7.1 is on CRAN.
     tryCatch(
       {
         effsize <- effectsize::effectsize(model,
           centrality = centrality,
           dispersion = dispersion,
+          ci = ci,
           ci_method = ci_method,
           rope_ci = rope_ci,
           type = es_type,
@@ -250,24 +243,6 @@ model_parameters.BFBayesFactor <- function(model,
 }
 
 
-#' p-values for Bayesian Models
-#'
-#' This function attempts to return, or compute, p-values of Bayesian models.
-#'
-#' @param model A statistical model.
-#' @inheritParams p_value
-#'
-#' @details
-#' For Bayesian models, the p-values corresponds to the *probability of
-#' direction* ([`bayestestR::p_direction()`]), which is converted to a p-value
-#' using `bayestestR::convert_pd_to_p()`.
-#'
-#' @return The p-values.
-#'
-#' @examples
-#' data(iris)
-#' model <- lm(Petal.Length ~ Sepal.Length + Species, data = iris)
-#' p_value(model)
 #' @export
 p_value.BFBayesFactor <- function(model, ...) {
   p <- bayestestR::p_direction(model)
