@@ -1,5 +1,69 @@
-#' @rdname model_parameters.stanreg
+#' @title Parameters from Bayesian Models
+#' @name model_parameters.brmsfit
+#'
+#' @description
+#' Model parameters from Bayesian models. This function internally calls
+#' [`bayestestR::describe_posterior()`] to get the relevant information for
+#' the output.
+#'
+#' @param model Bayesian model (including SEM from **blavaan**. May also be
+#' a data frame with posterior samples, however, `as_draws` must be set to
+#' `TRUE` (else, for data frames `NULL` is returned).
+#' @param ci Credible Interval (CI) level. Default to `0.95` (`95%`). See
+#' [bayestestR::ci()] for further details.
+#' @param group_level Logical, for multilevel models (i.e. models with random
+#' effects) and when `effects = "all"` or `effects = "random"`,
+#' include the parameters for each group level from random effects. If
+#' `group_level = FALSE` (the default), only information on SD and COR
+#' are shown.
+#' @param component Which type of parameters to return, such as parameters for the
+#' conditional model, the zero-inflation part of the model, the dispersion
+#' term, or other auxiliary parameters be returned? Applies to models with
+#' zero-inflation and/or dispersion formula, or if parameters such as `sigma`
+#' should be included. May be abbreviated. Note that the *conditional*
+#' component is also called *count* or *mean* component, depending on the
+#' model. There are three convenient shortcuts: `component = "all"` returns
+#' all possible parameters. If `component = "location"`, location parameters
+#' such as `conditional`, `zero_inflated`, or `smooth_terms`, are returned
+#' (everything that are fixed or random effects - depending on the `effects`
+#' argument - but no auxiliary parameters). For `component = "distributional"`
+#' (or `"auxiliary"`), components like `sigma`, `dispersion`, or `beta`
+#' (and other auxiliary parameters) are returned.
+#' @param as_draws Logical, if `TRUE` and `model` is of class `data.frame`,
+#' the data frame is treated as posterior samples and handled similar to
+#' Bayesian models. All arguments in `...` are passed to
+#' `model_parameters.draws()`.
+#' @inheritParams model_parameters.default
+#' @inheritParams bayestestR::describe_posterior
 #' @inheritParams insight::get_parameters
+#'
+#' @seealso [insight::standardize_names()] to rename columns into a consistent,
+#' standardized naming scheme.
+#'
+#' @note When `standardize = "refit"`, columns `diagnostic`, `bf_prior` and
+#' `priors` refer to the *original* `model`. If `model` is a data frame,
+#' arguments `diagnostic`, `bf_prior` and `priors` are ignored.
+#'
+#' There is also a
+#' [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
+#' implemented in the [**see**-package](https://easystats.github.io/see/).
+#'
+#' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
+#'
+#' @inheritSection model_parameters.zcpglm Model components
+#'
+#' @examples
+#' \donttest{
+#' library(parameters)
+#' if (require("rstanarm")) {
+#'   model <- suppressWarnings(stan_glm(
+#'     Sepal.Length ~ Petal.Length * Species,
+#'     data = iris, iter = 500, refresh = 0
+#'   ))
+#'   model_parameters(model)
+#' }
+#' }
+#' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.brmsfit <- function(model,
                                      centrality = "median",
@@ -71,6 +135,7 @@ model_parameters.brmsfit <- function(model,
       if (length(random_effect_levels) && isFALSE(group_level)) params <- params[-random_effect_levels, ]
     }
 
+    # add prettified names as attribute. Furthermore, group column is added
     params <- .add_pretty_names(params, model)
 
     # exponentiate coefficients and SE/CI, if requested
@@ -81,13 +146,14 @@ model_parameters.brmsfit <- function(model,
       ci,
       exponentiate,
       ci_method = ci_method,
+      group_level = group_level,
       verbose = verbose,
       ...
     )
 
     attr(params, "parameter_info") <- insight::clean_parameters(model)
     attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
-    class(params) <- unique(c("parameters_stan", "see_parameters_model", "parameters_model", class(params)))
+    class(params) <- unique(c("parameters_model", "see_parameters_model", class(params)))
   }
 
   params
@@ -207,11 +273,17 @@ model_parameters.brmsfit <- function(model,
 
 #' @export
 standard_error.brmsfit <- function(model,
-                                   effects = c("fixed", "random"),
-                                   component = c("all", "conditional", "zi", "zero_inflated"),
+                                   effects = "fixed",
+                                   component = "all",
                                    ...) {
-  effects <- match.arg(effects)
-  component <- match.arg(component)
+  effects <- insight::validate_argument(
+    effects,
+    c("fixed", "random")
+  )
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
 
   params <- insight::get_parameters(model, effects = effects, component = component, ...)
 
