@@ -18,21 +18,61 @@
 #' @seealso [insight::standardize_names()] to rename
 #'   columns into a consistent, standardized naming scheme.
 #'
-#' @examples
-#' library(parameters)
-#' if (require("pscl")) {
-#'   data("bioChemists")
-#'   model <- zeroinfl(art ~ fem + mar + kid5 + ment | kid5 + phd, data = bioChemists)
-#'   model_parameters(model)
-#' }
+#' @section Model components:
+#' Possible values for the `component` argument depend on the model class.
+#' Following are valid options:
+#' - `"all"`: returns all model components, applies to all models, but will only
+#'   have an effect for models with more than just the conditional model component.
+#' - `"conditional"`: only returns the conditional component, i.e. "fixed effects"
+#'   terms from the model. Will only have an effect for models with more than
+#'   just the conditional model component.
+#' - `"smooth_terms"`: returns smooth terms, only applies to GAMs (or similar
+#'   models that may contain smooth terms).
+#' - `"zero_inflated"` (or `"zi"`): returns the zero-inflation component.
+#' - `"dispersion"`: returns the dispersion model component. This is common
+#'   for models with zero-inflation or that can model the dispersion parameter.
+#' - `"instruments"`: for instrumental-variable or some fixed effects regression,
+#'   returns the instruments.
+#' - `"nonlinear"`: for non-linear models (like models of class `nlmerMod` or
+#'   `nls`), returns staring estimates for the nonlinear parameters.
+#' - `"correlation"`: for models with correlation-component, like `gls`, the
+#'   variables used to describe the correlation structure are returned.
+#'
+#' **Special models**
+#'
+#' Some model classes also allow rather uncommon options. These are:
+#' - **mhurdle**: `"infrequent_purchase"`, `"ip"`, and `"auxiliary"`
+#' - **BGGM**: `"correlation"` and `"intercept"`
+#' - **BFBayesFactor**, **glmx**: `"extra"`
+#' - **averaging**:`"conditional"` and `"full"`
+#' - **mjoint**: `"survival"`
+#' - **mfx**: `"precision"`, `"marginal"`
+#' - **betareg**, **DirichletRegModel**: `"precision"`
+#' - **mvord**: `"thresholds"` and `"correlation"`
+#' - **clm2**: `"scale"`
+#' - **selection**: `"selection"`, `"outcome"`, and `"auxiliary"`
+#' - **lavaan**: One or more of `"regression"`, `"correlation"`, `"loading"`,
+#'   `"variance"`, `"defined"`, or `"mean"`. Can also be `"all"` to include
+#'   all components.
+#'
+#' For models of class `brmsfit` (package **brms**), even more options are
+#' possible for the `component` argument, which are not all documented in detail
+#' here.
+#'
+#' @examplesIf require("pscl")
+#' data("bioChemists", package = "pscl")
+#' model <- pscl::zeroinfl(
+#'   art ~ fem + mar + kid5 + ment | kid5 + phd,
+#'   data = bioChemists
+#' )
+#' model_parameters(model)
 #' @return A data frame of indices related to the model's parameters.
-#' @inheritParams simulate_model
 #' @export
 model_parameters.zcpglm <- function(model,
                                     ci = 0.95,
                                     bootstrap = FALSE,
                                     iterations = 1000,
-                                    component = c("all", "conditional", "zi", "zero_inflated"),
+                                    component = "all",
                                     standardize = NULL,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
@@ -42,7 +82,7 @@ model_parameters.zcpglm <- function(model,
                                     drop = NULL,
                                     verbose = TRUE,
                                     ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(component, c("all", "conditional", "zi", "zero_inflated"))
 
   # fix argument, if model has no zi-part
   if (!insight::model_info(model, verbose = FALSE)$is_zero_inflated && component != "conditional") {
@@ -93,12 +133,13 @@ model_parameters.zcpglm <- function(model,
 
 
 #' @export
-standard_error.zcpglm <- function(model,
-                                  component = c("all", "conditional", "zi", "zero_inflated"),
-                                  ...) {
+standard_error.zcpglm <- function(model, component = "all", ...) {
   insight::check_if_installed("cplm")
 
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
   junk <- utils::capture.output(stats <- cplm::summary(model)$coefficients) # nolint
   params <- insight::get_parameters(model)
 
@@ -119,34 +160,14 @@ standard_error.zcpglm <- function(model,
 }
 
 
-#' p-values for Models with Zero-Inflation
-#'
-#' This function attempts to return, or compute, p-values of hurdle and
-#' zero-inflated models.
-#'
-#' @param model A statistical model.
-#' @inheritParams p_value
-#' @inheritParams simulate_model
-#' @inheritParams standard_error
-#'
-#' @return
-#' A data frame with at least two columns: the parameter names and the p-values.
-#' Depending on the model, may also include columns for model components etc.
-#'
-#' @examples
-#' if (require("pscl", quietly = TRUE)) {
-#'   data("bioChemists")
-#'   model <- zeroinfl(art ~ fem + mar + kid5 | kid5 + phd, data = bioChemists)
-#'   p_value(model)
-#'   p_value(model, component = "zi")
-#' }
 #' @export
-p_value.zcpglm <- function(model,
-                           component = c("all", "conditional", "zi", "zero_inflated"),
-                           ...) {
+p_value.zcpglm <- function(model, component = "all", ...) {
   insight::check_if_installed("cplm")
 
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
   junk <- utils::capture.output(stats <- cplm::summary(model)$coefficients) # nolint
   params <- insight::get_parameters(model)
 
@@ -168,7 +189,6 @@ p_value.zcpglm <- function(model,
 
 
 
-
 ########## .bcpglm ---------------
 
 #' @export
@@ -180,10 +200,8 @@ p_value.bcplm <- p_value.brmsfit
 
 
 
-
 ########## .cpglm ---------------
 
-
 #' @export
 p_value.cpglm <- function(model, ...) {
   insight::check_if_installed("cplm")
@@ -213,12 +231,8 @@ standard_error.cpglm <- function(model, ...) {
 
 
 
-
-
 ########## .cpglmm ---------------
 
-
-#' @rdname model_parameters.merMod
 #' @export
 model_parameters.cpglmm <- function(model,
                                     ci = 0.95,
@@ -238,7 +252,7 @@ model_parameters.cpglmm <- function(model,
                                     ...) {
   # p-values, CI and se might be based on different df-methods
   ci_method <- .check_df_method(ci_method)
-  effects <- match.arg(effects, choices = c("fixed", "random", "all"))
+  effects <- insight::validate_argument(effects, c("fixed", "random", "all"))
 
   # standardize only works for fixed effects...
   if (!is.null(standardize) && standardize != "refit") {
@@ -296,7 +310,6 @@ standard_error.cpglmm <- function(model, ...) {
 
 
 
-
 # tools --------------------
 
 .check_df_method <- function(df_method) {
@@ -306,7 +319,13 @@ standard_error.cpglmm <- function(model, ...) {
       insight::format_alert("Satterthwaite or Kenward-Rogers approximation of degrees of freedom is only available for linear mixed models.")
       df_method <- "wald"
     }
-    df_method <- match.arg(df_method, choices = c("wald", "normal", "residual", "ml1", "betwithin", "profile", "boot", "uniroot"))
+    df_method <- insight::validate_argument(
+      df_method,
+      c(
+        "wald", "normal", "residual", "ml1", "betwithin", "profile",
+        "boot", "uniroot"
+      )
+    )
   }
   df_method
 }
