@@ -4,8 +4,159 @@
 # model_parameters -----
 
 
+#' @title Parameters from Mixed Models
+#' @name model_parameters.glmmTMB
+#'
+#' @description Parameters from (linear) mixed models.
+#'
+#' @param model A mixed model.
+#' @param effects Should parameters for fixed effects (`"fixed"`), random
+#'   effects (`"random"`), or both (`"all"`) be returned? Only applies
+#'   to mixed models. May be abbreviated. If the calculation of random effects
+#'   parameters takes too long, you may use `effects = "fixed"`.
+#' @param wb_component Logical, if `TRUE` and models contains within- and
+#'   between-effects (see `datawizard::demean()`), the `Component` column
+#'   will indicate which variables belong to the within-effects,
+#'   between-effects, and cross-level interactions. By default, the
+#'   `Component` column indicates, which parameters belong to the
+#'   conditional or zero-inflation component of the model.
+#' @param include_sigma Logical, if `TRUE`, includes the residual standard
+#'   deviation. For mixed models, this is defined as the sum of the distribution-specific
+#'   variance and the variance for the additive overdispersion term (see
+#'   [insight::get_variance()] for details). Defaults to `FALSE` for mixed models
+#'   due to the longer computation time.
+#' @param ci_random Logical, if `TRUE`, includes the confidence intervals for
+#'   random effects parameters. Only applies if `effects` is not `"fixed"` and
+#'   if `ci` is not `NULL`. Set `ci_random = FALSE` if computation of the model
+#'   summary is too much time consuming. By default, `ci_random = NULL`, which
+#'   uses a heuristic to guess if computation of confidence intervals for random
+#'   effects is fast enough or not. For models with larger sample size and/or
+#'   more complex random effects structures, confidence intervals will not be
+#'   computed by default, for simpler models or fewer observations, confidence
+#'   intervals will be included. Set explicitly to `TRUE` or `FALSE` to enforce
+#'   or omit calculation of confidence intervals.
+#' @param ... Arguments passed to or from other methods. For instance, when
+#'   `bootstrap = TRUE`, arguments like `type` or `parallel` are passed down to
+#'   `bootstrap_model()`.
+#'
+#' Further non-documented arguments are:
+#'
+#' - `digits`, `p_digits`, `ci_digits` and `footer_digits` to set the number of
+#'   digits for the output. `groups` can be used to group coefficients. These
+#'   arguments will be passed to the print-method, or can directly be used in
+#'   `print()`, see documentation in [`print.parameters_model()`].
+#' - If `s_value = TRUE`, the p-value will be replaced by the S-value in the
+#'   output (cf. _Rafi and Greenland 2020_).
+#' - `pd` adds an additional column with the _probability of direction_ (see
+#'   [`bayestestR::p_direction()`] for details). Furthermore, see 'Examples' for
+#'   this function.
+#' - For developers, whose interest mainly is to get a "tidy" data frame of
+#'   model summaries, it is recommended to set `pretty_names = FALSE` to speed
+#'   up computation of the summary table.
+#'
+#' @inheritParams model_parameters.default
+#' @inheritParams model_parameters.brmsfit
 #' @inheritParams simulate_model
-#' @rdname model_parameters.merMod
+#'
+#' @inheritSection model_parameters.zcpglm Model components
+#'
+#' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
+#'
+#' @section Confidence intervals for random effects variances:
+#' For models of class `merMod` and `glmmTMB`, confidence intervals for random
+#' effect variances can be calculated.
+#'
+#' - For models of from package **lme4**, when `ci_method` is either `"profile"`
+#' or `"boot"`, and `effects` is either `"random"` or `"all"`, profiled resp.
+#' bootstrapped confidence intervals are computed for the random effects.
+#'
+#' - For all other options of `ci_method`, and only when the **merDeriv**
+#' package is installed, confidence intervals for random effects are based on
+#' normal-distribution approximation, using the delta-method to transform
+#' standard errors for constructing the intervals around the log-transformed
+#' SD parameters. These are than back-transformed, so that random effect
+#' variances, standard errors and confidence intervals are shown on the original
+#' scale. Due to the transformation, the intervals are asymmetrical, however,
+#' they are within the correct bounds (i.e. no negative interval for the SD,
+#' and the interval for the correlations is within the range from -1 to +1).
+#'
+#' - For models of class `glmmTMB`, confidence intervals for random effect
+#' variances always use a Wald t-distribution approximation.
+#'
+#' @section Singular fits (random effects variances near zero):
+#' If a model is "singular", this means that some dimensions of the
+#' variance-covariance matrix have been estimated as exactly zero. This
+#' often occurs for mixed models with complex random effects structures.
+#'
+#' There is no gold-standard about how to deal with singularity and which
+#' random-effects specification to choose. One way is to fully go Bayesian
+#' (with informative priors). Other proposals are listed in the documentation
+#' of [`performance::check_singularity()`]. However, since version 1.1.9, the
+#' **glmmTMB** package allows to use priors in a frequentist framework, too. One
+#' recommendation is to use a Gamma prior (_Chung et al. 2013_). The mean may
+#' vary from 1 to very large values (like `1e8`), and the shape parameter should
+#' be set to a value of 2.5. You can then `update()` your model with the specified
+#' prior. In **glmmTMB**, the code would look like this:
+#'
+#' ```
+#' # "model" is an object of class gmmmTMB
+#' prior <- data.frame(
+#'   prior = "gamma(1, 2.5)",  # mean can be 1, but even 1e8
+#'   class = "ranef"           # for random effects
+#' )
+#' model_with_priors <- update(model, priors = prior)
+#' ```
+#'
+#' Large values for the mean parameter of the Gamma prior have no large impact
+#' on the random effects variances in terms of a "bias". Thus, if `1` doesn't
+#' fix the singular fit, you can safely try larger values.
+#'
+#' @section Dispersion parameters in *glmmTMB*:
+#' For some models from package **glmmTMB**, both the dispersion parameter and
+#' the residual variance from the random effects parameters are shown. Usually,
+#' these are the same but presented on different scales, e.g.
+#'
+#' ```
+#' model <- glmmTMB(Sepal.Width ~ Petal.Length + (1|Species), data = iris)
+#' exp(fixef(model)$disp) # 0.09902987
+#' sigma(model)^2         # 0.09902987
+#' ```
+#'
+#' For models where the dispersion parameter and the residual variance are
+#' the same, only the residual variance is shown in the output.
+#'
+#' @seealso [insight::standardize_names()] to
+#'   rename columns into a consistent, standardized naming scheme.
+#'
+#' @note If the calculation of random effects parameters takes too long, you may
+#' use `effects = "fixed"`. There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
+#' implemented in the [**see**-package](https://easystats.github.io/see/).
+#'
+#' @references
+#' Chung Y, Rabe-Hesketh S, Dorie V, Gelman A, and Liu J. 2013. "A Nondegenerate
+#' Penalized Likelihood Estimator for Variance Parameters in Multilevel Models."
+#' Psychometrika 78 (4): 685–709. \doi{10.1007/s11336-013-9328-2}
+#'
+#' @examplesIf require("lme4") && require("glmmTMB")
+#' library(parameters)
+#' data(mtcars)
+#' model <- lme4::lmer(mpg ~ wt + (1 | gear), data = mtcars)
+#' model_parameters(model)
+#'
+#' \donttest{
+#' data(Salamanders, package = "glmmTMB")
+#' model <- glmmTMB::glmmTMB(
+#'   count ~ spp + mined + (1 | site),
+#'   ziformula = ~mined,
+#'   family = poisson(),
+#'   data = Salamanders
+#' )
+#' model_parameters(model, effects = "all")
+#'
+#' model <- lme4::lmer(mpg ~ wt + (1 | gear), data = mtcars)
+#' model_parameters(model, bootstrap = TRUE, iterations = 50, verbose = FALSE)
+#' }
+#' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.glmmTMB <- function(model,
                                      ci = 0.95,
@@ -47,8 +198,14 @@ model_parameters.glmmTMB <- function(model,
   ci_method <- .check_df_method(ci_method)
 
   # which components to return?
-  effects <- match.arg(effects, choices = c("fixed", "random", "all"))
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion"))
+  effects <- insight::validate_argument(
+    effects,
+    c("fixed", "random", "all")
+  )
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
 
   # standardize only works for fixed effects...
   if (!is.null(standardize) && standardize != "refit") {
@@ -258,7 +415,6 @@ model_parameters.glmmTMB <- function(model,
 # ci -----
 
 
-#' @rdname ci.default
 #' @export
 ci.glmmTMB <- function(x,
                        ci = 0.95,
@@ -268,8 +424,14 @@ ci.glmmTMB <- function(x,
                        verbose = TRUE,
                        ...) {
   method <- tolower(method)
-  method <- match.arg(method, choices = c("wald", "normal", "ml1", "betwithin", "profile", "uniroot", "robust"))
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion"))
+  method <- insight::validate_argument(
+    method,
+    c("wald", "normal", "ml1", "betwithin", "profile", "uniroot", "robust")
+  )
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
 
   if (is.null(.check_component(x, component, verbose = verbose))) {
     return(NULL)
@@ -307,16 +469,20 @@ ci.glmmTMB <- function(x,
 
 # standard_error -----
 
-
-#' @rdname standard_error
 #' @export
 standard_error.glmmTMB <- function(model,
                                    effects = "fixed",
                                    component = "all",
                                    verbose = TRUE,
                                    ...) {
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion"))
-  effects <- match.arg(effects, choices = c("fixed", "random"))
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
+  effects <- insight::validate_argument(
+    effects,
+    c("fixed", "random")
+  )
 
   dot_args <- .check_dots(
     dots = list(...),
@@ -327,12 +493,14 @@ standard_error.glmmTMB <- function(model,
   )
 
   if (effects == "random") {
-    if (!requireNamespace("TMB", quietly = TRUE) && !requireNamespace("glmmTMB", quietly = TRUE)) {
+    if (!all(insight::check_if_installed(c("TMB", "glmmTMB"), quietly = TRUE))) {
       return(NULL)
     }
+
     s1 <- TMB::sdreport(model$obj, getJointPrecision = TRUE)
     s2 <- sqrt(s1$diag.cov.random)
     rand.ef <- glmmTMB::ranef(model)[[1]]
+
     rand.se <- lapply(rand.ef, function(.x) {
       cnt <- nrow(.x) * ncol(.x)
       s3 <- s2[1:cnt]
@@ -370,14 +538,16 @@ standard_error.glmmTMB <- function(model,
 # simulate model -----
 
 
-#' @rdname simulate_model
 #' @export
 simulate_model.glmmTMB <- function(model,
                                    iterations = 1000,
-                                   component = c("all", "conditional", "zi", "zero_inflated", "dispersion"),
+                                   component = "all",
                                    verbose = FALSE,
                                    ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
   info <- insight::model_info(model, verbose = FALSE)
 
   ## TODO remove is.list() when insight 0.8.3 on CRAN
@@ -461,8 +631,6 @@ simulate_model.glmmTMB <- function(model,
 
 # simulate_parameters -----
 
-
-#' @rdname simulate_parameters
 #' @export
 simulate_parameters.glmmTMB <- function(model,
                                         iterations = 1000,
