@@ -1,6 +1,5 @@
 # model parameters ---------------------
 
-
 #' @export
 model_parameters.logitor <- function(model,
                                      ci = 0.95,
@@ -37,7 +36,7 @@ model_parameters.poissonmfx <- function(model,
                                         ci = 0.95,
                                         bootstrap = FALSE,
                                         iterations = 1000,
-                                        component = c("all", "conditional", "marginal"),
+                                        component = "all",
                                         standardize = NULL,
                                         exponentiate = FALSE,
                                         p_adjust = NULL,
@@ -45,7 +44,10 @@ model_parameters.poissonmfx <- function(model,
                                         drop = NULL,
                                         verbose = TRUE,
                                         ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "marginal")
+  )
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -79,19 +81,21 @@ model_parameters.probitmfx <- model_parameters.poissonmfx
 model_parameters.negbinmfx <- model_parameters.poissonmfx
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.betaor <- function(model,
                                     ci = 0.95,
                                     bootstrap = FALSE,
                                     iterations = 1000,
-                                    component = c("conditional", "precision", "all"),
+                                    component = "conditional",
                                     standardize = NULL,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
                                     verbose = TRUE,
                                     ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("conditional", "precision", "all")
+  )
   model_parameters.betareg(
     model$fit,
     ci = ci,
@@ -106,13 +110,12 @@ model_parameters.betaor <- function(model,
 }
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.betamfx <- function(model,
                                      ci = 0.95,
                                      bootstrap = FALSE,
                                      iterations = 1000,
-                                     component = c("all", "conditional", "precision", "marginal"),
+                                     component = "all",
                                      standardize = NULL,
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
@@ -120,7 +123,10 @@ model_parameters.betamfx <- function(model,
                                      drop = NULL,
                                      verbose = TRUE,
                                      ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision", "marginal")
+  )
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -143,10 +149,8 @@ model_parameters.betamfx <- function(model,
 
 
 
-
 # ci ------------------
 
-
 #' @export
 ci.logitor <- function(x, ci = 0.95, method = NULL, ...) {
   .ci_generic(model = x$fit, ci = ci, method = method, ...)
@@ -162,12 +166,11 @@ ci.negbinirr <- ci.logitor
 
 
 #' @export
-ci.poissonmfx <- function(x,
-                          ci = 0.95,
-                          component = c("all", "conditional", "marginal"),
-                          method = NULL,
-                          ...) {
-  component <- match.arg(component)
+ci.poissonmfx <- function(x, ci = 0.95, component = "all", method = NULL, ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "marginal")
+  )
   .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
@@ -185,11 +188,11 @@ ci.probitmfx <- ci.poissonmfx
 
 
 #' @export
-ci.betaor <- function(x,
-                      ci = 0.95,
-                      component = c("all", "conditional", "precision"),
-                      ...) {
-  component <- match.arg(component)
+ci.betaor <- function(x, ci = 0.95, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision")
+  )
   .ci_generic(model = x$fit, ci = ci, dof = Inf, component = component)
 }
 
@@ -198,18 +201,19 @@ ci.betaor <- function(x,
 ci.betamfx <- function(x,
                        ci = 0.95,
                        method = NULL,
-                       component = c("all", "conditional", "precision", "marginal"),
+                       component = "all",
                        ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision", "marginal")
+  )
   .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
 
 
-
 # standard error ------------------
 
-
 #' @export
 standard_error.negbin <- standard_error.default
 
@@ -229,9 +233,7 @@ standard_error.negbinirr <- standard_error.logitor
 
 
 #' @export
-standard_error.poissonmfx <- function(model,
-                                      component = "all",
-                                      ...) {
+standard_error.poissonmfx <- function(model, component = "all", ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- stats::coef(summary(model$fit))
   se <- c(as.vector(model$mfxest[, 2]), as.vector(cs[, 2]))
@@ -242,7 +244,10 @@ standard_error.poissonmfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component, choices = c("all", "conditional", "marginal"))
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "marginal")
+  )
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -264,18 +269,17 @@ standard_error.negbinmfx <- standard_error.poissonmfx
 
 
 #' @export
-standard_error.betaor <- function(model,
-                                  component = c("all", "conditional", "precision"),
-                                  ...) {
-  component <- match.arg(component)
+standard_error.betaor <- function(model, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision")
+  )
   standard_error.betareg(model$fit, component = component, ...)
 }
 
 
 #' @export
-standard_error.betamfx <- function(model,
-                                   component = "all",
-                                   ...) {
+standard_error.betamfx <- function(model, component = "all", ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- do.call(rbind, stats::coef(summary(model$fit)))
   se <- c(as.vector(model$mfxest[, 2]), as.vector(cs[, 2]))
@@ -286,7 +290,10 @@ standard_error.betamfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component, choices = c("all", "conditional", "precision", "marginal"))
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision", "marginal")
+  )
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -298,38 +305,8 @@ standard_error.betamfx <- function(model,
 
 # p values ------------------
 
-
-#' p-values for Marginal Effects Models
-#'
-#' This function attempts to return, or compute, p-values of marginal effects
-#' models from package **mfx**.
-#'
-#' @param model A statistical model.
-#' @param component Should all parameters, parameters for the conditional model,
-#'   precision-component or marginal effects be returned? `component` may be one
-#'   of `"conditional"`, `"precision"`, `"marginal"` or `"all"` (default).
-#' @param ... Currently not used.
-#'
-#' @return A data frame with at least two columns: the parameter names and the
-#'   p-values. Depending on the model, may also include columns for model
-#'   components etc.
-#'
-#' @examples
-#' if (require("mfx", quietly = TRUE)) {
-#'   set.seed(12345)
-#'   n <- 1000
-#'   x <- rnorm(n)
-#'   y <- rnegbin(n, mu = exp(1 + 0.5 * x), theta = 0.5)
-#'   d <- data.frame(y, x)
-#'   model <- poissonmfx(y ~ x, data = d)
-#'
-#'   p_value(model)
-#'   p_value(model, component = "marginal")
-#' }
 #' @export
-p_value.poissonmfx <- function(model,
-                               component = c("all", "conditional", "marginal"),
-                               ...) {
+p_value.poissonmfx <- function(model, component = "all", ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- stats::coef(summary(model$fit))
   p <- c(as.vector(model$mfxest[, 4]), as.vector(cs[, 4]))
@@ -340,7 +317,10 @@ p_value.poissonmfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "marginal")
+  )
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -375,21 +355,18 @@ p_value.probitmfx <- p_value.poissonmfx
 p_value.negbinmfx <- p_value.poissonmfx
 
 
-#' @rdname p_value.poissonmfx
 #' @export
-p_value.betaor <- function(model,
-                           component = c("all", "conditional", "precision"),
-                           ...) {
-  component <- match.arg(component)
+p_value.betaor <- function(model, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision")
+  )
   p_value.betareg(model$fit, component = component, ...)
 }
 
 
-#' @rdname p_value.poissonmfx
 #' @export
-p_value.betamfx <- function(model,
-                            component = c("all", "conditional", "precision", "marginal"),
-                            ...) {
+p_value.betamfx <- function(model, component = "all", ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- do.call(rbind, stats::coef(summary(model$fit)))
   p <- c(as.vector(model$mfxest[, 4]), as.vector(cs[, 4]))
@@ -400,7 +377,10 @@ p_value.betamfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision", "marginal")
+  )
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -410,16 +390,14 @@ p_value.betamfx <- function(model,
 
 
 
-
 # simulate model ------------------
 
-
 #' @export
-simulate_model.betaor <- function(model,
-                                  iterations = 1000,
-                                  component = c("all", "conditional", "precision"),
-                                  ...) {
-  component <- match.arg(component)
+simulate_model.betaor <- function(model, iterations = 1000, component = "all", ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "precision")
+  )
 
   simulate_model.betareg(model$fit,
     iterations = iterations,
