@@ -3,7 +3,6 @@
 # model parameters -------------------
 
 
-#' @inheritParams model_parameters.merMod
 #' @export
 model_parameters.wbm <- function(model,
                                  ci = 0.95,
@@ -53,6 +52,39 @@ model_parameters.wbm <- function(model,
 model_parameters.wbgee <- model_parameters.wbm
 
 
+#' @export
+model_parameters.asym <- function(model,
+                                  ci = 0.95,
+                                  ci_method = NULL,
+                                  bootstrap = FALSE,
+                                  iterations = 1000,
+                                  standardize = NULL,
+                                  exponentiate = FALSE,
+                                  p_adjust = NULL,
+                                  summary = getOption("parameters_summary", FALSE),
+                                  include_info = getOption("parameters_info", FALSE),
+                                  keep = NULL,
+                                  drop = NULL,
+                                  verbose = TRUE,
+                                  ...) {
+  params <- model_parameters.default(
+    model,
+    ci = ci,
+    ci_method = ci_method,
+    bootstrap = bootstrap,
+    iterations = iterations,
+    standardize = standardize,
+    exponentiate = exponentiate,
+    p_adjust = p_adjust,
+    include_info = include_info,
+    keep = keep,
+    drop = drop,
+    verbose = verbose,
+    ...
+  )
+  attr(params, "no_caption") <- TRUE
+  params
+}
 
 
 # standard errors -------------------
