@@ -4,16 +4,6 @@
 # plm ---------------------------
 
 
-#' @export
-degrees_of_freedom.plm <- function(model, method = "wald", ...) {
-  if (identical(method, "normal")) {
-    return(Inf)
-  } else {
-    model$df.residual
-  }
-}
-
-
 #' @export
 standard_error.plm <- function(model, vcov = NULL, vcov_args = NULL, verbose = TRUE, ...) {
   dots <- list(...)
