@@ -4,7 +4,6 @@
 ########### .vgam ---------------
 
 
-#' @rdname model_parameters.cgam
 #' @export
 model_parameters.vgam <- model_parameters.gam
 
@@ -23,19 +22,10 @@ standard_error.vgam <- function(model, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.vgam <- function(model, ...) {
-  params <- insight::get_parameters(model)
-  out <- stats::setNames(rep(NA, nrow(params)), params$Parameter)
-  out[names(model@nl.df)] <- model@nl.df
-  out
-}
-
-
 #' @export
 p_value.vgam <- function(model, ...) {
   stat <- insight::get_statistic(model)
-  stat$p <- as.vector(stats::pchisq(stat$Statistic, df = degrees_of_freedom(model), lower.tail = FALSE))
+  stat$p <- as.vector(stats::pchisq(stat$Statistic, df = insight::get_df(model), lower.tail = FALSE))
 
   stat[c("Parameter", "p", "Component")]
 }
@@ -56,9 +46,7 @@ simulate_model.vgam <- function(model, iterations = 1000, ...) {
 
 #' @export
 p_value.vglm <- function(model, ...) {
-  if (!requireNamespace("VGAM", quietly = TRUE)) {
-    stop("Package `VGAM` required.", call. = FALSE)
-  }
+  insight::check_if_installed("VGAM")
 
   cs <- VGAM::summary(model)@coef3
   p <- cs[, 4]
@@ -83,7 +71,7 @@ standard_error.vglm <- function(model, ...) {
 
 
 
-# ci.vgam <- function(x, ci = .95, component = c("all", "conditional", "smooth"), ...) {
+# ci.vgam <- function(x, ci = 0.95, component = c("all", "conditional", "smooth"), ...) {
 #   component <- match.arg(component)
 #
 #   # dof and SE
