@@ -24,6 +24,12 @@ test_that("Robust post hoc", {
   expect_error(standardize_parameters(model, method = "basic", robust = TRUE, two_sd = TRUE), NA)
 })
 
+# Labels ------------------------------------------------------------------
+test_that("Preserve labels", {
+  fit <- lm(Sepal.Length ~ Species, data = iris)
+  out <- standardize_parameters(fit)
+  expect_snapshot(print(out))
+})
 
 # model_parameters -------------------------------
 test_that("standardize_parameters (model_parameters)", {
@@ -302,15 +308,17 @@ test_that("standardize_parameters (Bayes)", {
     )
   })
 
+  set.seed(1234)
   expect_equal(
     suppressWarnings(standardize_parameters(model, method = "refit")$Std_Median[1:4]),
-    c(0.065, -0.094, -0.100, 0.862),
-    tolerance = 0.01
+    c(0.03787, -0.06088, -0.04807, 0.84067),
+    tolerance = 0.1
   )
 
+  set.seed(1234)
   expect_equal(
     suppressWarnings(standardize_parameters(model, method = "posthoc")$Std_Median[1:4]),
-    c(0, -0.058, -0.053, 0.838),
+    c(0, -0.0586, -0.05258, 0.83883),
     tolerance = 0.01
   )
 
@@ -322,6 +330,7 @@ test_that("standardize_parameters (Bayes)", {
 
 # Pseudo - GLMM --------------------------------
 test_that("standardize_parameters (Pseudo - GLMM)", {
+  skip_if_not_installed("datawizard", minimum_version = "0.12.0")
   skip_on_cran()
   skip_if_not_installed("lme4")
   set.seed(1)
